==> segatex-7.991.tar.gz: segatex-7.991/src/breakif.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef BREAKIF_H
#define BREAKIF_H

#include <qregexp.h>
#include <qdialog.h>
#include <qradiobutton.h>
#include <q3textedit.h>
#include <qlabel.h>
#include <qlayout.h>
#include <qcheckbox.h>
#include <q3process.h>
//Added by qt3to4:
#include <Q3VBoxLayout>
#include <Q3HBoxLayout>


class Q3TextEdit;
class QLineEdit;
class QPushButton;
class Q3Process;

class BreakIf: public QDialog
{
	Q_OBJECT
public:
	BreakIf(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
protected:

private slots:
	void breakif_clicked();
	void breakif_base_process();
	void readFromStdout();
	void processExited();
	void readFromOutputFile();
private:
	Q3Process *process;
	Q3TextEdit *textEdit1;
	Q3VBoxLayout *firstLayout;
	Q3HBoxLayout *leftLayout;
	Q3VBoxLayout *rightLayout;
	Q3HBoxLayout *mainLayout;
	QPushButton *breakifButton;
	QPushButton *closeButton;
	QString grep_str;
	QString grep_str_echo;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;
};

#endif

==> segatex-8.600.tar.gz: segatex-8.600/src/breakif.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef BREAKIF_H
#define BREAKIF_H

#include <QRegExp>
#include <QDialog>
#include <QRadioButton>
#include <QTextEdit>
#include <QLabel>
#include <QLayout>
#include <QCheckBox>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QProcess>
#include <QDir>


class QTextEdit;
class QLineEdit;
class QPushButton;

class BreakIf: public QDialog
{
	Q_OBJECT
public:
	BreakIf(QWidget *parent = 0, const char *name = 0);
public slots:
signals:
protected:

private slots:
	void breakif_clicked();
	void breakif_base_process();
	void readFromStdout();
	//void processExited();
	//void readFromOutputFile();
//newly added
	void updateOutputTextEdit();
        void processExited(int, QProcess::ExitStatus);
private:
	QProcess *process;
	QTextEdit *textEdit1;
	QVBoxLayout *firstLayout;
	QHBoxLayout *leftLayout;
	QVBoxLayout *rightLayout;
	QHBoxLayout *mainLayout;
	QPushButton *breakifButton;
	QPushButton *closeButton;
	QString grep_str;
	QString grep_str_echo;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;

        QStringList::Iterator it_d;
        QStringList files;
};

#endif
